@@ -139,7 +139,9 @@ class DataInputStream(object):
                             "\n[debug] self.stream: " + str(self.stream) + \
                             "\n[debug] self.recv(1): " + str(self.recv(1)) + " format: " + str(format))
 
-            return unpack('b', self.stream.read(1))[0]
+            # readByte is only used in ib/ext/EReader.py
+            # 0 to be returned if empty
+            return 0
 
 
 class DataOutputStream(object):
